Skip to contents

Copy PowerPoint template to specified file path

Usage

kda_copy_pptx_template(file_path)

Arguments

file_path

A single string specifying the file path where the PowerPoint template will be copied to.

Value

NULL, invisibly. The PowerPoint template is copied to the specified file path. If the directory does not exist, it is created.