Skip to contents

A short description...

Usage

kda_performance(model)

Arguments

model

A fitted model object.

Value

A list with two elements: out, a data frame with performance metrics for each predictor, and perf, a data frame with detailed performance statistics.