Copy a codebook template to a specified file path
Usage
dp_copy_codebook_template(file_path)
Arguments
- file_path
The file path where the codebook template should be copied.
Value
NULL, invisibly. The codebook template is copied to the specified file path. If the directory does not exist, it is created.