R/kda.R
kda_performance.Rd
A short description...
kda_performance(model)
A fitted model object.
A list with two elements: out, a data frame with performance metrics for each predictor, and perf, a data frame with detailed performance statistics.
out
perf