A short description...
Arguments
- data
A data frame containing the outcome and predictors. Optional if
modelis provided.- outcome
A single string naming the outcome variable. Optional if
modelis provided.- predictors
A character vector of predictor variable names. Optional if
modelis provided.- model
A fitted regression model object. Optional if
data,outcome, andpredictorsare provided.- diagnostics
A logical indicating whether to compute model diagnostics. Defaults to
FALSE. IfTRUE, see here for interpretation and possible solutions.- importance_method
One of
"auto","domir","jrw", or"sumOfCoefficients". Defaults to"auto".- importance_barPlot_args
Optional. A list of additional arguments passed to the importance bar plot function. See
kda_importance_barPlot()for details..- performance_barPlot_args
Optional. A list of additional arguments passed to the performance bar plot function. See
kda_performance_barPlot()for details..- ipma_scatterPlot_args
Optional. A list of additional arguments passed to the IPMA scatter plot function. See
kda_ipma_scatterPlot()for details..