Save KDA data for chart in Excel template
Arguments
- ipma_scatterPlot_data
The data frame containing the data used for the IPMA scatter plot. This should be the output of the
ipma_scatterPlotelement in the list returned bykda_regression().- file_path
A single string specifying the file path where the Excel file will be saved.