R/utils.R
ya_choose_file.Rd
Choose a file and return its path
ya_choose_file()
A single string representing the full file path of the chosen file. The function normalizes the file path to use forward slashes and ensures that the selected file exists.